@@ -1,6 +1,6 @@
 # --* encoding: utf-8 *--
 
-from .helper import get_attributes
+from .helper import get_attr_names
 from .value_object import ValueObject
 from json.encoder import JSONEncoder
 
@@ -17,12 +17,12 @@ class Encoder(JSONEncoder):
 
     def default(self, o):
         '''Overrides json.JSONEncoder.default() to not rise TypeError.'''
-        names = get_attributes(o)
+        names = get_attr_names(o)
         result = {}
         for name in names:
             attr = getattr(o, name)
             if isinstance(attr, ValueObject):
-                return self.default(attr)
+                result[name] = self.default(attr)
             else:
                 result[name] = attr
         return result
