@@ -1,6 +1,6 @@
 # --* encoding: utf-8 *--
 
-from .helper import get_attributes
+from .helper import get_attr_names
 
 
 class ValueObject(object):
@@ -14,16 +14,11 @@ class ValueObject(object):
         '''Return True if other is same class and has same attribute value.'''
         if not isinstance(other, getattr(self, '__class__')):
             return False
-        for name in get_attributes(self):
+        for name in get_attr_names(self):
             self_attr = getattr(self, name)
             other_attr = getattr(other, name)
-            if isinstance(self_attr, (list, tuple)):
-                for a in self_attr:
-                    if a not in other_attr:
-                        return False
-            else:
-                if self_attr != other_attr:
-                    return False
+            if self_attr != other_attr:
+                return False
         return True
 
     def __ne__(self, other):
@@ -35,8 +30,9 @@ class ValueObject(object):
         Return value is depend on it's attribute value.
         This method calculates it's attributets hashcode recursively.
         '''
+        attributes = [getattr(self, name) for name in get_attr_names(self)]
         return reduce(lambda p, c: p * self.__hash(c),
-                      [getattr(self, name) for name in get_attributes(self)],
+                      attributes,
                       1)
 
     def __hash(self, o):
